pub struct EpochCommittees {
inner: Arc<RwLock<Inner>>,
fetcher: Arc<Fetcher>,
update_fixed_block_reward_lock: Arc<Mutex<()>>,
epoch_height: BlockNumber,
}Expand description
Type to describe DA and Stake memberships.
Fields
inner: Arc<RwLock<Inner>>fetcher: Arc<Fetcher>update_fixed_block_reward_lock: Arc<Mutex<()>>epoch_height: BlockNumberImplementations
Sourceimpl EpochCommittees
impl EpochCommittees
pub fn epoch_height(&self) -> BlockNumber
pub fn first_epoch(&self) -> Option<EpochNumber>
pub fn fetcher(&self) -> &Fetcher
pub fn fixed_block_reward(&self) -> Option<RewardAmount>
Sourcepub fn latest_peer_config(&self, key: &PubKey) -> Option<PeerConfig<SeqTypes>>
pub fn latest_peer_config(&self, key: &PubKey) -> Option<PeerConfig<SeqTypes>>
Find the most recent stake-table entry for key.
Scanns loaded epochs from highest to lowest and falling back to the genesis bootstrap committee.
Sourceasync fn fetch_and_update_fixed_block_reward(
&self,
epoch: EpochNumber,
) -> Result<RewardAmount>
async fn fetch_and_update_fixed_block_reward( &self, epoch: EpochNumber, ) -> Result<RewardAmount>
Fetch the fixed block reward and update it if its None. We used a fixed block reward for version v3 Version v4 uses the dynamic block reward Assumes the stake table contract proxy address does not change
Sourceasync fn calculate_dynamic_block_reward(
&self,
epoch: EpochNumber,
header: &Header,
validators: &AuthenticatedValidatorMap,
) -> Result<Option<RewardAmount>>
async fn calculate_dynamic_block_reward( &self, epoch: EpochNumber, header: &Header, validators: &AuthenticatedValidatorMap, ) -> Result<Option<RewardAmount>>
Calculates the dynamic block reward for a given block header within an epoch.
The reward is based on a dynamic inflation rate computed from the current stake ratio (p),
where p = total_stake / total_supply. The inflation function R(p) is defined piecewise:
- If
p <= 0.01: R(p) = 0.03 / sqrt(2 * 0.01) - Else: R(p) = 0.03 / sqrt(2 * p)
Sourcepub fn epoch_block_reward(&self, epoch: EpochNumber) -> Option<RewardAmount>
pub fn epoch_block_reward(&self, epoch: EpochNumber) -> Option<RewardAmount>
This function just returns the stored block reward in epoch committee
Sourcepub fn get_validator_index(
&self,
epoch: EpochNumber,
bls_key: &PubKey,
) -> Option<usize>
pub fn get_validator_index( &self, epoch: EpochNumber, bls_key: &PubKey, ) -> Option<usize>
Get the index of a validator’s BLS key in the epoch’s stake table. Returns None if the validator is not in the stake table for this epoch.
The index corresponds to the position in the leader_counts array in V6 headers.
pub fn active_validators( &self, e: EpochNumber, ) -> Result<AuthenticatedValidatorMap>
pub fn address(&self, e: EpochNumber, key: &BLSPubKey) -> Result<Address>
pub fn get_validator_config( &self, epoch: EpochNumber, key: &BLSPubKey, ) -> Result<AuthenticatedValidator<BLSPubKey>>
pub fn new_stake<B: Into<BlockNumber>>( committee_members: Vec<PeerConfig<SeqTypes>>, da_members: Vec<PeerConfig<SeqTypes>>, fixed_block_reward: Option<RewardAmount>, fetcher: Fetcher, epoch_height: B, ) -> Self
pub async fn reload_stake(&mut self, limit: u64)
Sourcefn map_header<E, F, R>(&self, epoch: E, f: F) -> Option<R>
fn map_header<E, F, R>(&self, epoch: E, f: F) -> Option<R>
Get root leaf header for a given epoch
fn randomized_committee( &self, epoch: EpochNumber, drb: DrbResult, ) -> Option<RandomizedCommittee<StakeTableEntry<PubKey>>>